@@ -109,6 +109,12 @@ class FileServerConnector:
             thumbnail = dict_to_dataclass(thumbnail, FileLink)
         return original, thumbnail
 
+    async def upload_from(self, file_url: str) -> FileLink:
+        answer = await self._connector.post(
+            "/file/add_from", payload={"file_url": file_url}, headers=self._construct_headers()
+        )
+        return dict_to_dataclass(answer, FileLink)
+
     async def add_file(self, file: bytes, filename: str, *args, **kwargs) -> FileLink:
         warnings.warn("is deprecated, replace it with 'upload_file'", DeprecationWarning)
         return (await self.upload_file(filename, file))[0]
